# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .llm_literal_json_schema_property import LlmLiteralJsonSchemaProperty


class AstNodeInput_AddOperator(UncheckedBaseModel):
    type: typing.Literal["add_operator"] = "add_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_AndOperator(UncheckedBaseModel):
    type: typing.Literal["and_operator"] = "and_operator"
    children: typing.List["AstNodeInput"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_BooleanLiteral(UncheckedBaseModel):
    type: typing.Literal["boolean_literal"] = "boolean_literal"
    value: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_ConditionalOperator(UncheckedBaseModel):
    type: typing.Literal["conditional_operator"] = "conditional_operator"
    condition: "AstNodeInput"
    true_expression: typing_extensions.Annotated[
        "AstNodeInput", FieldMetadata(alias="trueExpression"), pydantic.Field(alias="trueExpression")
    ]
    false_expression: typing_extensions.Annotated[
        "AstNodeInput", FieldMetadata(alias="falseExpression"), pydantic.Field(alias="falseExpression")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_DivOperator(UncheckedBaseModel):
    type: typing.Literal["div_operator"] = "div_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_DynamicVariable(UncheckedBaseModel):
    type: typing.Literal["dynamic_variable"] = "dynamic_variable"
    name: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_EqOperator(UncheckedBaseModel):
    type: typing.Literal["eq_operator"] = "eq_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_GtOperator(UncheckedBaseModel):
    type: typing.Literal["gt_operator"] = "gt_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_GteOperator(UncheckedBaseModel):
    type: typing.Literal["gte_operator"] = "gte_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_Llm(UncheckedBaseModel):
    type: typing.Literal["llm"] = "llm"
    value_schema: typing.Optional[LlmLiteralJsonSchemaProperty] = None
    prompt: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_LtOperator(UncheckedBaseModel):
    type: typing.Literal["lt_operator"] = "lt_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_LteOperator(UncheckedBaseModel):
    type: typing.Literal["lte_operator"] = "lte_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_MulOperator(UncheckedBaseModel):
    type: typing.Literal["mul_operator"] = "mul_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_NeqOperator(UncheckedBaseModel):
    type: typing.Literal["neq_operator"] = "neq_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_NullLiteral(UncheckedBaseModel):
    type: typing.Literal["null_literal"] = "null_literal"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_NumberLiteral(UncheckedBaseModel):
    type: typing.Literal["number_literal"] = "number_literal"
    value: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_OrOperator(UncheckedBaseModel):
    type: typing.Literal["or_operator"] = "or_operator"
    children: typing.List["AstNodeInput"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_StringLiteral(UncheckedBaseModel):
    type: typing.Literal["string_literal"] = "string_literal"
    value: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstNodeInput_SubOperator(UncheckedBaseModel):
    type: typing.Literal["sub_operator"] = "sub_operator"
    left: "AstNodeInput"
    right: "AstNodeInput"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


AstNodeInput = typing_extensions.Annotated[
    typing.Union[
        AstNodeInput_AddOperator,
        AstNodeInput_AndOperator,
        AstNodeInput_BooleanLiteral,
        AstNodeInput_ConditionalOperator,
        AstNodeInput_DivOperator,
        AstNodeInput_DynamicVariable,
        AstNodeInput_EqOperator,
        AstNodeInput_GtOperator,
        AstNodeInput_GteOperator,
        AstNodeInput_Llm,
        AstNodeInput_LtOperator,
        AstNodeInput_LteOperator,
        AstNodeInput_MulOperator,
        AstNodeInput_NeqOperator,
        AstNodeInput_NullLiteral,
        AstNodeInput_NumberLiteral,
        AstNodeInput_OrOperator,
        AstNodeInput_StringLiteral,
        AstNodeInput_SubOperator,
    ],
    UnionMetadata(discriminant="type"),
]
from .ast_and_operator_node_input import AstAndOperatorNodeInput  # noqa: E402, I001
from .ast_conditional_operator_node_input import AstConditionalOperatorNodeInput  # noqa: E402, I001
from .ast_division_operator_node_input import AstDivisionOperatorNodeInput  # noqa: E402, I001
from .ast_equals_operator_node_input import AstEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_greater_than_operator_node_input import AstGreaterThanOperatorNodeInput  # noqa: E402, I001
from .ast_greater_than_or_equals_operator_node_input import AstGreaterThanOrEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_less_than_operator_node_input import AstLessThanOperatorNodeInput  # noqa: E402, I001
from .ast_less_than_or_equals_operator_node_input import AstLessThanOrEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_multiplication_operator_node_input import AstMultiplicationOperatorNodeInput  # noqa: E402, I001
from .ast_not_equals_operator_node_input import AstNotEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_or_operator_node_input import AstOrOperatorNodeInput  # noqa: E402, I001
from .ast_subtraction_operator_node_input import AstSubtractionOperatorNodeInput  # noqa: E402, I001
from .ast_addition_operator_node_input import AstAdditionOperatorNodeInput  # noqa: E402, I001

update_forward_refs(
    AstNodeInput_AddOperator,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_AndOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_ConditionalOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_DivOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_EqOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_GtOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_GteOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_LtOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_LteOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_MulOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_NeqOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_OrOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
update_forward_refs(
    AstNodeInput_SubOperator,
    AstAdditionOperatorNodeInput=AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.delete_workspace_webhook_response_model import DeleteWorkspaceWebhookResponseModel
from ..types.patch_workspace_webhook_response_model import PatchWorkspaceWebhookResponseModel
from ..types.webhook_hmac_settings import WebhookHmacSettings
from ..types.workspace_create_webhook_response_model import WorkspaceCreateWebhookResponseModel
from ..types.workspace_webhook_event_type import WorkspaceWebhookEventType
from ..types.workspace_webhook_list_response_model import WorkspaceWebhookListResponseModel
from .raw_client import AsyncRawWebhooksClient, RawWebhooksClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WebhooksClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWebhooksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWebhooksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWebhooksClient
        """
        return self._raw_client

    def list(
        self, *, include_usages: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspaceWebhookListResponseModel:
        """
        List all webhooks for a workspace

        Parameters
        ----------
        include_usages : typing.Optional[bool]
            Whether to include active usages of the webhook, only usable by admins

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceWebhookListResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.webhooks.list(
            include_usages=False,
        )
        """
        _response = self._raw_client.list(include_usages=include_usages, request_options=request_options)
        return _response.data

    def create(
        self, *, settings: WebhookHmacSettings, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspaceCreateWebhookResponseModel:
        """
        Create a new webhook for the workspace with the specified authentication type.

        Parameters
        ----------
        settings : WebhookHmacSettings
            Webhook settings object containing auth_type and corresponding configuration

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceCreateWebhookResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs, WebhookHmacSettings

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.webhooks.create(
            settings=WebhookHmacSettings(
                name="name",
                webhook_url="webhook_url",
            ),
        )
        """
        _response = self._raw_client.create(settings=settings, request_options=request_options)
        return _response.data

    def delete(
        self, webhook_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteWorkspaceWebhookResponseModel:
        """
        Delete the specified workspace webhook

        Parameters
        ----------
        webhook_id : str
            The unique ID for the webhook

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteWorkspaceWebhookResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.webhooks.delete(
            webhook_id="G007vmtq9uWYl7SUW9zGS8GZZa1K",
        )
        """
        _response = self._raw_client.delete(webhook_id, request_options=request_options)
        return _response.data

    def update(
        self,
        webhook_id: str,
        *,
        is_disabled: bool,
        name: str,
        retry_enabled: typing.Optional[bool] = OMIT,
        request_headers: typing.Optional[typing.Dict[str, typing.Optional[str]]] = OMIT,
        events: typing.Optional[typing.Sequence[WorkspaceWebhookEventType]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PatchWorkspaceWebhookResponseModel:
        """
        Update the specified workspace webhook

        Parameters
        ----------
        webhook_id : str
            The unique ID for the webhook

        is_disabled : bool
            Whether to disable or enable the webhook

        name : str
            The display name of the webhook (used for display purposes only).

        retry_enabled : typing.Optional[bool]
            Whether to enable automatic retries for transient failures (5xx, 429, timeout)

        request_headers : typing.Optional[typing.Dict[str, typing.Optional[str]]]
            A list of request headers to include with the webhook delivery (optional)

        events : typing.Optional[typing.Sequence[WorkspaceWebhookEventType]]
            The complete set of workspace-level events this webhook should be subscribed to. The webhook is added to the events in the list and removed from any not in the list. Omit to leave the current event subscriptions unchanged.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PatchWorkspaceWebhookResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.webhooks.update(
            webhook_id="G007vmtq9uWYl7SUW9zGS8GZZa1K",
            is_disabled=True,
            name="My Callback Webhook",
        )
        """
        _response = self._raw_client.update(
            webhook_id,
            is_disabled=is_disabled,
            name=name,
            retry_enabled=retry_enabled,
            request_headers=request_headers,
            events=events,
            request_options=request_options,
        )
        return _response.data


class AsyncWebhooksClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWebhooksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWebhooksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWebhooksClient
        """
        return self._raw_client

    async def list(
        self, *, include_usages: typing.Optional[bool] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspaceWebhookListResponseModel:
        """
        List all webhooks for a workspace

        Parameters
        ----------
        include_usages : typing.Optional[bool]
            Whether to include active usages of the webhook, only usable by admins

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceWebhookListResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.webhooks.list(
                include_usages=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(include_usages=include_usages, request_options=request_options)
        return _response.data

    async def create(
        self, *, settings: WebhookHmacSettings, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspaceCreateWebhookResponseModel:
        """
        Create a new webhook for the workspace with the specified authentication type.

        Parameters
        ----------
        settings : WebhookHmacSettings
            Webhook settings object containing auth_type and corresponding configuration

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspaceCreateWebhookResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs, WebhookHmacSettings

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.webhooks.create(
                settings=WebhookHmacSettings(
                    name="name",
                    webhook_url="webhook_url",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(settings=settings, request_options=request_options)
        return _response.data

    async def delete(
        self, webhook_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteWorkspaceWebhookResponseModel:
        """
        Delete the specified workspace webhook

        Parameters
        ----------
        webhook_id : str
            The unique ID for the webhook

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteWorkspaceWebhookResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.webhooks.delete(
                webhook_id="G007vmtq9uWYl7SUW9zGS8GZZa1K",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(webhook_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        webhook_id: str,
        *,
        is_disabled: bool,
        name: str,
        retry_enabled: typing.Optional[bool] = OMIT,
        request_headers: typing.Optional[typing.Dict[str, typing.Optional[str]]] = OMIT,
        events: typing.Optional[typing.Sequence[WorkspaceWebhookEventType]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PatchWorkspaceWebhookResponseModel:
        """
        Update the specified workspace webhook

        Parameters
        ----------
        webhook_id : str
            The unique ID for the webhook

        is_disabled : bool
            Whether to disable or enable the webhook

        name : str
            The display name of the webhook (used for display purposes only).

        retry_enabled : typing.Optional[bool]
            Whether to enable automatic retries for transient failures (5xx, 429, timeout)

        request_headers : typing.Optional[typing.Dict[str, typing.Optional[str]]]
            A list of request headers to include with the webhook delivery (optional)

        events : typing.Optional[typing.Sequence[WorkspaceWebhookEventType]]
            The complete set of workspace-level events this webhook should be subscribed to. The webhook is added to the events in the list and removed from any not in the list. Omit to leave the current event subscriptions unchanged.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        PatchWorkspaceWebhookResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.webhooks.update(
                webhook_id="G007vmtq9uWYl7SUW9zGS8GZZa1K",
                is_disabled=True,
                name="My Callback Webhook",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            webhook_id,
            is_disabled=is_disabled,
            name=name,
            retry_enabled=retry_enabled,
            request_headers=request_headers,
            events=events,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .....types.dubbing_bulk_target_segment_update_response import DubbingBulkTargetSegmentUpdateResponse
from .....types.dubbing_regenerate_response import DubbingRegenerateResponse
from .....types.dubbing_target_segment_update_request import DubbingTargetSegmentUpdateRequest
from .....types.dubbing_target_segment_update_response import DubbingTargetSegmentUpdateResponse
from .....types.dubbing_target_transcript_response import DubbingTargetTranscriptResponse
from .raw_client import AsyncRawTranscriptClient, RawTranscriptClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TranscriptClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTranscriptClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTranscriptClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTranscriptClient
        """
        return self._raw_client

    def get(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DubbingTargetTranscriptResponse:
        """
        A language target's transcript: source segments with their translations.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingTargetTranscriptResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.language.transcript.get(
            project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
            language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
        )
        """
        _response = self._raw_client.get(project_id, language_id, request_options=request_options)
        return _response.data

    def update_segment(
        self,
        project_id: str,
        language_id: str,
        segment_id: str,
        *,
        request: DubbingTargetSegmentUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingTargetSegmentUpdateResponse:
        """
        Enterprise only. Edit a segment's translation for a language target.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segment_id : str
            Identifier of the segment to edit.

        request : DubbingTargetSegmentUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingTargetSegmentUpdateResponse
            Successful Response

        Examples
        --------
        from elevenlabs import DubbingTargetSegmentUpdateRequest, ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.language.transcript.update_segment(
            project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
            language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
            segment_id="0199a3f0-1c2d-7abc-8def-0123456789ab",
            request=DubbingTargetSegmentUpdateRequest(
                translation="Bienvenido a nuestra última demostración de producto.",
            ),
        )
        """
        _response = self._raw_client.update_segment(
            project_id, language_id, segment_id, request=request, request_options=request_options
        )
        return _response.data

    def update_segments(
        self,
        project_id: str,
        language_id: str,
        *,
        segments: typing.Dict[str, DubbingTargetSegmentUpdateRequest],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingBulkTargetSegmentUpdateResponse:
        """
        Enterprise only. Edit several segments' translations for a language target in one atomic request.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segments : typing.Dict[str, DubbingTargetSegmentUpdateRequest]
            Map of segment id to the translation edit to apply to that segment.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingBulkTargetSegmentUpdateResponse
            Successful Response

        Examples
        --------
        from elevenlabs import DubbingTargetSegmentUpdateRequest, ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.language.transcript.update_segments(
            project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
            language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
            segments={
                "0199a3f0-1c2d-7abc-8def-0123456789ab": DubbingTargetSegmentUpdateRequest(
                    translation="Bienvenido a nuestra última demostración de producto.",
                ),
                "0199a3f0-3e4f-7abc-8def-0123456789cd": DubbingTargetSegmentUpdateRequest(
                    translation="Empecemos.",
                ),
            },
        )
        """
        _response = self._raw_client.update_segments(
            project_id, language_id, segments=segments, request_options=request_options
        )
        return _response.data

    def regenerate(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DubbingRegenerateResponse:
        """
        Enterprise only. Re-dub a target from its edited transcript, re-synthesizing only the edited regions (charged like a generation). Conflicts when the target has no edits to apply -- nothing is dispatched and nothing is charged.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingRegenerateResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.language.transcript.regenerate(
            project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
            language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
        )
        """
        _response = self._raw_client.regenerate(project_id, language_id, request_options=request_options)
        return _response.data


class AsyncTranscriptClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTranscriptClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTranscriptClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTranscriptClient
        """
        return self._raw_client

    async def get(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DubbingTargetTranscriptResponse:
        """
        A language target's transcript: source segments with their translations.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingTargetTranscriptResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.language.transcript.get(
                project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
                language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(project_id, language_id, request_options=request_options)
        return _response.data

    async def update_segment(
        self,
        project_id: str,
        language_id: str,
        segment_id: str,
        *,
        request: DubbingTargetSegmentUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingTargetSegmentUpdateResponse:
        """
        Enterprise only. Edit a segment's translation for a language target.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segment_id : str
            Identifier of the segment to edit.

        request : DubbingTargetSegmentUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingTargetSegmentUpdateResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs, DubbingTargetSegmentUpdateRequest

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.language.transcript.update_segment(
                project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
                language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
                segment_id="0199a3f0-1c2d-7abc-8def-0123456789ab",
                request=DubbingTargetSegmentUpdateRequest(
                    translation="Bienvenido a nuestra última demostración de producto.",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_segment(
            project_id, language_id, segment_id, request=request, request_options=request_options
        )
        return _response.data

    async def update_segments(
        self,
        project_id: str,
        language_id: str,
        *,
        segments: typing.Dict[str, DubbingTargetSegmentUpdateRequest],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingBulkTargetSegmentUpdateResponse:
        """
        Enterprise only. Edit several segments' translations for a language target in one atomic request.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segments : typing.Dict[str, DubbingTargetSegmentUpdateRequest]
            Map of segment id to the translation edit to apply to that segment.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingBulkTargetSegmentUpdateResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs, DubbingTargetSegmentUpdateRequest

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.language.transcript.update_segments(
                project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
                language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
                segments={
                    "0199a3f0-1c2d-7abc-8def-0123456789ab": DubbingTargetSegmentUpdateRequest(
                        translation="Bienvenido a nuestra última demostración de producto.",
                    ),
                    "0199a3f0-3e4f-7abc-8def-0123456789cd": DubbingTargetSegmentUpdateRequest(
                        translation="Empecemos.",
                    ),
                },
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_segments(
            project_id, language_id, segments=segments, request_options=request_options
        )
        return _response.data

    async def regenerate(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DubbingRegenerateResponse:
        """
        Enterprise only. Re-dub a target from its edited transcript, re-synthesizing only the edited regions (charged like a generation). Conflicts when the target has no edits to apply -- nothing is dispatched and nothing is charged.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingRegenerateResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.language.transcript.regenerate(
                project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
                language_id="lang_1001kwkyxp0je6ktn4knsfrasx5s",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.regenerate(project_id, language_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

WorkspaceWebhookEventType = typing.Union[
    typing.Literal["voice_library_removal_notice", "speech_to_text", "agent_qa"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class AgentTransferOp_Pop(UncheckedBaseModel):
    type: typing.Literal["pop"] = "pop"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AgentTransferOp_Push(UncheckedBaseModel):
    type: typing.Literal["push"] = "push"
    return_node_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AgentTransferOp_Replace(UncheckedBaseModel):
    type: typing.Literal["replace"] = "replace"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


AgentTransferOp = typing_extensions.Annotated[
    typing.Union[AgentTransferOp_Pop, AgentTransferOp_Push, AgentTransferOp_Replace], UnionMetadata(discriminant="type")
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel


class CustomToolApiSchemaConfig(UncheckedBaseModel):
    """
    Parameter schema for an integration tool the brain answers itself.

    Unlike ``WebhookToolApiSchemaConfig`` there is no HTTP transport: ``handler``
    receives the LLM's parameters and produces the tool result.
    """

    request_body_schema: "ObjectJsonSchemaPropertyOutput" = pydantic.Field()
    """
    JSON schema for the parameters the LLM provides to this tool.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput  # noqa: E402, I001
from .array_json_schema_property_output_items import ArrayJsonSchemaPropertyOutputItems  # noqa: E402, I001
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput  # noqa: E402, I001
from .object_json_schema_property_output_properties_value import ObjectJsonSchemaPropertyOutputPropertiesValue  # noqa: E402, I001

update_forward_refs(
    CustomToolApiSchemaConfig,
    ArrayJsonSchemaPropertyOutput=ArrayJsonSchemaPropertyOutput,
    ArrayJsonSchemaPropertyOutputItems=ArrayJsonSchemaPropertyOutputItems,
    ObjectJsonSchemaPropertyOutput=ObjectJsonSchemaPropertyOutput,
    ObjectJsonSchemaPropertyOutputPropertiesValue=ObjectJsonSchemaPropertyOutputPropertiesValue,
)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.parse_error import ParsingError
from .....core.request_options import RequestOptions
from .....core.serialization import convert_and_respect_annotation_metadata
from .....core.unchecked_base_model import construct_type
from .....errors.unprocessable_entity_error import UnprocessableEntityError
from .....types.dubbing_bulk_target_segment_update_response import DubbingBulkTargetSegmentUpdateResponse
from .....types.dubbing_regenerate_response import DubbingRegenerateResponse
from .....types.dubbing_target_segment_update_request import DubbingTargetSegmentUpdateRequest
from .....types.dubbing_target_segment_update_response import DubbingTargetSegmentUpdateResponse
from .....types.dubbing_target_transcript_response import DubbingTargetTranscriptResponse
from pydantic import ValidationError

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTranscriptClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DubbingTargetTranscriptResponse]:
        """
        A language target's transcript: source segments with their translations.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DubbingTargetTranscriptResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingTargetTranscriptResponse,
                    construct_type(
                        type_=DubbingTargetTranscriptResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_segment(
        self,
        project_id: str,
        language_id: str,
        segment_id: str,
        *,
        request: DubbingTargetSegmentUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[DubbingTargetSegmentUpdateResponse]:
        """
        Enterprise only. Edit a segment's translation for a language target.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segment_id : str
            Identifier of the segment to edit.

        request : DubbingTargetSegmentUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DubbingTargetSegmentUpdateResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript/segment/{jsonable_encoder(segment_id)}",
            method="PATCH",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=DubbingTargetSegmentUpdateRequest, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingTargetSegmentUpdateResponse,
                    construct_type(
                        type_=DubbingTargetSegmentUpdateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_segments(
        self,
        project_id: str,
        language_id: str,
        *,
        segments: typing.Dict[str, DubbingTargetSegmentUpdateRequest],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[DubbingBulkTargetSegmentUpdateResponse]:
        """
        Enterprise only. Edit several segments' translations for a language target in one atomic request.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segments : typing.Dict[str, DubbingTargetSegmentUpdateRequest]
            Map of segment id to the translation edit to apply to that segment.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DubbingBulkTargetSegmentUpdateResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript/segments",
            method="PATCH",
            json={
                "segments": convert_and_respect_annotation_metadata(
                    object_=segments, annotation=typing.Dict[str, DubbingTargetSegmentUpdateRequest], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingBulkTargetSegmentUpdateResponse,
                    construct_type(
                        type_=DubbingBulkTargetSegmentUpdateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def regenerate(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DubbingRegenerateResponse]:
        """
        Enterprise only. Re-dub a target from its edited transcript, re-synthesizing only the edited regions (charged like a generation). Conflicts when the target has no edits to apply -- nothing is dispatched and nothing is charged.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DubbingRegenerateResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript/regenerate",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingRegenerateResponse,
                    construct_type(
                        type_=DubbingRegenerateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTranscriptClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DubbingTargetTranscriptResponse]:
        """
        A language target's transcript: source segments with their translations.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DubbingTargetTranscriptResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingTargetTranscriptResponse,
                    construct_type(
                        type_=DubbingTargetTranscriptResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_segment(
        self,
        project_id: str,
        language_id: str,
        segment_id: str,
        *,
        request: DubbingTargetSegmentUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[DubbingTargetSegmentUpdateResponse]:
        """
        Enterprise only. Edit a segment's translation for a language target.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segment_id : str
            Identifier of the segment to edit.

        request : DubbingTargetSegmentUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DubbingTargetSegmentUpdateResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript/segment/{jsonable_encoder(segment_id)}",
            method="PATCH",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=DubbingTargetSegmentUpdateRequest, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingTargetSegmentUpdateResponse,
                    construct_type(
                        type_=DubbingTargetSegmentUpdateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_segments(
        self,
        project_id: str,
        language_id: str,
        *,
        segments: typing.Dict[str, DubbingTargetSegmentUpdateRequest],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[DubbingBulkTargetSegmentUpdateResponse]:
        """
        Enterprise only. Edit several segments' translations for a language target in one atomic request.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        segments : typing.Dict[str, DubbingTargetSegmentUpdateRequest]
            Map of segment id to the translation edit to apply to that segment.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DubbingBulkTargetSegmentUpdateResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript/segments",
            method="PATCH",
            json={
                "segments": convert_and_respect_annotation_metadata(
                    object_=segments, annotation=typing.Dict[str, DubbingTargetSegmentUpdateRequest], direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingBulkTargetSegmentUpdateResponse,
                    construct_type(
                        type_=DubbingBulkTargetSegmentUpdateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def regenerate(
        self, project_id: str, language_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DubbingRegenerateResponse]:
        """
        Enterprise only. Re-dub a target from its edited transcript, re-synthesizing only the edited regions (charged like a generation). Conflicts when the target has no edits to apply -- nothing is dispatched and nothing is charged.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project.

        language_id : str
            Identifier of the language target.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DubbingRegenerateResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/dubbing/project/{jsonable_encoder(project_id)}/language/{jsonable_encoder(language_id)}/transcript/regenerate",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DubbingRegenerateResponse,
                    construct_type(
                        type_=DubbingRegenerateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .finetune_created_by import FinetuneCreatedBy
from .finetune_visibility import FinetuneVisibility
from .music_finetune_failure_reason import MusicFinetuneFailureReason
from .music_finetune_status import MusicFinetuneStatus


class MusicFinetuneResponseModel(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    Unique identifier of the finetune.
    """

    name: str = pydantic.Field()
    """
    Name of the finetune.
    """

    tags: typing.List[str] = pydantic.Field()
    """
    Tags associated with the finetune.
    """

    primary_genre: typing.Optional[str] = pydantic.Field(default=None)
    """
    Primary musical genre of the finetune.
    """

    model_id: str = pydantic.Field()
    """
    The base music model the finetune was trained on.
    """

    created_at: dt.datetime = pydantic.Field()
    """
    When the finetune was created (UTC).
    """

    visibility: FinetuneVisibility = pydantic.Field()
    """
    Who can access this finetune: `private` (only you), `workspace` (members of your workspace), `public` (ElevenLabs-curated, available to everyone).
    """

    created_by: FinetuneCreatedBy = pydantic.Field()
    """
    Who created the finetune: `self`, `workspace`, or `elevenlabs`.
    """

    status: MusicFinetuneStatus = pydantic.Field()
    """
    Training lifecycle status: pending, in_progress, completed, failed, and blocked.
    """

    training_progress: float = pydantic.Field()
    """
    Training progress from 0.0 to 1.0.
    """

    failure_reason: typing.Optional[MusicFinetuneFailureReason] = pydantic.Field(default=None)
    """
    Reason the finetune failed or was blocked, if applicable.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .alerting_monitor_config import AlertingMonitorConfig
from .alerting_webhook_notifier import AlertingWebhookNotifier


class AlertingSettings(UncheckedBaseModel):
    """
    Alerting configuration used at both per-agent and per-workspace level.

    All fields are optional overrides; the cascade resolver fills in defaults
    when they are unset. Notifiers stack and dedupe (by webhook_id) across the
    workspace and agent layers rather than overriding each other.

    Cascade order for per-monitor threshold and auto-resolve: agent → workspace →
    system default.
    """

    monitor_configs: typing.Optional[typing.Dict[str, AlertingMonitorConfig]] = pydantic.Field(default=None)
    """
    Alerting configuration keyed by monitor name.
    """

    auto_resolve_after_inactive_minutes: typing.Optional[int] = pydantic.Field(default=None)
    """
    How many minutes an alert can stay inactive before it is auto-resolved. Unset values fall through to the next layer.
    """

    notifiers: typing.Optional[typing.List[AlertingWebhookNotifier]] = pydantic.Field(default=None)
    """
    Delivery channels for alert lifecycle notifications. Stacked and deduped by webhook_id with other layers.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class AutoGenerationMetadata(UncheckedBaseModel):
    """
    Metadata for an automatically generated simulation test.

    Tracks the origin and context of tests that were auto-generated from
    conversations, including the source conversation, topic, and evaluation
    criteria the test covers.
    """

    agent_id: str = pydantic.Field()
    """
    Agent whose simulation library this test belongs to.
    """

    stable_topic_id: str = pydantic.Field()
    """
    Stable topic id (from topic discovery) this test covers.
    """

    criteria_id: str = pydantic.Field()
    """
    Evaluation criterion id this test targets.
    """

    topic_label: str = pydantic.Field()
    """
    Human-readable topic label at generation time.
    """

    source_conversation_id: str = pydantic.Field()
    """
    Conversation the test was generated from.
    """

    generated_at_unix: int = pydantic.Field()
    """
    Unix timestamp (seconds) when the test was generated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DubbingLanguageOutputs(UncheckedBaseModel):
    """
    Signed, time-limited download URLs for a language target's outputs.
    """

    lossless_audio: typing.Optional[str] = pydantic.Field(default=None)
    """
    Signed URL of the dubbed lossless audio track.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from ... import core
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.dubbing_project_list_response import DubbingProjectListResponse
from ...types.dubbing_project_response import DubbingProjectResponse
from .raw_client import AsyncRawProjectClient, RawProjectClient
from .types.project_create_request_model_id import ProjectCreateRequestModelId
from .types.project_list_request_sort_direction import ProjectListRequestSortDirection

if typing.TYPE_CHECKING:
    from .language.client import AsyncLanguageClient, LanguageClient
    from .transcript.client import AsyncTranscriptClient, TranscriptClient
# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ProjectClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawProjectClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._language: typing.Optional[LanguageClient] = None
        self._transcript: typing.Optional[TranscriptClient] = None

    @property
    def with_raw_response(self) -> RawProjectClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawProjectClient
        """
        return self._raw_client

    def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        status: typing.Optional[str] = None,
        sort_direction: typing.Optional[ProjectListRequestSortDirection] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingProjectListResponse:
        """
        List the workspace's dubbing projects (cursor-paginated).

        Parameters
        ----------
        cursor : typing.Optional[str]
            Pagination cursor from a previous response's next_cursor.

        page_size : typing.Optional[int]
            Number of projects per page (max 100).

        status : typing.Optional[str]
            Filter to projects in this status (preparing, ready, failed).

        sort_direction : typing.Optional[ProjectListRequestSortDirection]
            Sort by creation time (default 'DESCENDING').

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingProjectListResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.list(
            page_size=20,
        )
        """
        _response = self._raw_client.list(
            cursor=cursor,
            page_size=page_size,
            status=status,
            sort_direction=sort_direction,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        *,
        file: typing.Optional[core.File] = OMIT,
        source_url: typing.Optional[str] = OMIT,
        reference: typing.Optional[str] = OMIT,
        source_language: typing.Optional[str] = OMIT,
        model_id: typing.Optional[ProjectCreateRequestModelId] = OMIT,
        keyterms: typing.Optional[typing.List[str]] = OMIT,
        webhook_ids: typing.Optional[typing.List[str]] = OMIT,
        target_language: typing.Optional[str] = OMIT,
        transcript: typing.Optional[core.File] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingProjectResponse:
        """
        Create a dubbing project from an uploaded file or a source URL.

        Parameters
        ----------
        file : typing.Optional[core.File]
            See core.File for more documentation

        source_url : typing.Optional[str]
            Public URL to fetch the source media from. Provide this or file.

        reference : typing.Optional[str]
            Optional free-form string (max 500 characters) to identify the project on your end.

        source_language : typing.Optional[str]
            BCP-47 language tag of the source media; must be a language the transcription model supports. Any region or script subtag is ignored, since transcription is per-language. Omit to auto-detect.

        model_id : typing.Optional[ProjectCreateRequestModelId]
            Default dubbing model id ('dubbing_v1' or 'dubbing_v2') for the project's language targets; a target may override it. Omit to use the system default.

        keyterms : typing.Optional[typing.List[str]]
            Key terms to bias transcription/translation toward (e.g. product or brand names). At most 1000 terms; each term at most 50 characters and 5 words; the characters `<>{}[]\\` are not allowed.

        webhook_ids : typing.Optional[typing.List[str]]
            Ids of workspace webhooks to notify when this project becomes ready or fails, and when any of its languages completes or fails. At most 3; each must be a webhook configured in your workspace.

        target_language : typing.Optional[str]
            Optional shortcut: also create a language target in this BCP-47 language, queued to start once the project is ready. Must be a language the dubbing model supports, and a region-qualified tag must be one of the supported dialects.

        transcript : typing.Optional[core.File]
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingProjectResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.create(
            source_url="https://example.com/promo.mp4",
            source_language="en",
            reference="Q3 marketing video",
        )
        """
        _response = self._raw_client.create(
            file=file,
            source_url=source_url,
            reference=reference,
            source_language=source_language,
            model_id=model_id,
            keyterms=keyterms,
            webhook_ids=webhook_ids,
            target_language=target_language,
            transcript=transcript,
            request_options=request_options,
        )
        return _response.data

    def get(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DubbingProjectResponse:
        """
        Full project detail, including its language target ids.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project to fetch.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingProjectResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.get(
            project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
        )
        """
        _response = self._raw_client.get(project_id, request_options=request_options)
        return _response.data

    def delete(self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Delete a project and its language targets.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.dubbing.project.delete(
            project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
        )
        """
        _response = self._raw_client.delete(project_id, request_options=request_options)
        return _response.data

    @property
    def language(self):
        if self._language is None:
            from .language.client import LanguageClient  # noqa: E402

            self._language = LanguageClient(client_wrapper=self._client_wrapper)
        return self._language

    @property
    def transcript(self):
        if self._transcript is None:
            from .transcript.client import TranscriptClient  # noqa: E402

            self._transcript = TranscriptClient(client_wrapper=self._client_wrapper)
        return self._transcript


class AsyncProjectClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawProjectClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._language: typing.Optional[AsyncLanguageClient] = None
        self._transcript: typing.Optional[AsyncTranscriptClient] = None

    @property
    def with_raw_response(self) -> AsyncRawProjectClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawProjectClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        status: typing.Optional[str] = None,
        sort_direction: typing.Optional[ProjectListRequestSortDirection] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingProjectListResponse:
        """
        List the workspace's dubbing projects (cursor-paginated).

        Parameters
        ----------
        cursor : typing.Optional[str]
            Pagination cursor from a previous response's next_cursor.

        page_size : typing.Optional[int]
            Number of projects per page (max 100).

        status : typing.Optional[str]
            Filter to projects in this status (preparing, ready, failed).

        sort_direction : typing.Optional[ProjectListRequestSortDirection]
            Sort by creation time (default 'DESCENDING').

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingProjectListResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.list(
                page_size=20,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            cursor=cursor,
            page_size=page_size,
            status=status,
            sort_direction=sort_direction,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        *,
        file: typing.Optional[core.File] = OMIT,
        source_url: typing.Optional[str] = OMIT,
        reference: typing.Optional[str] = OMIT,
        source_language: typing.Optional[str] = OMIT,
        model_id: typing.Optional[ProjectCreateRequestModelId] = OMIT,
        keyterms: typing.Optional[typing.List[str]] = OMIT,
        webhook_ids: typing.Optional[typing.List[str]] = OMIT,
        target_language: typing.Optional[str] = OMIT,
        transcript: typing.Optional[core.File] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DubbingProjectResponse:
        """
        Create a dubbing project from an uploaded file or a source URL.

        Parameters
        ----------
        file : typing.Optional[core.File]
            See core.File for more documentation

        source_url : typing.Optional[str]
            Public URL to fetch the source media from. Provide this or file.

        reference : typing.Optional[str]
            Optional free-form string (max 500 characters) to identify the project on your end.

        source_language : typing.Optional[str]
            BCP-47 language tag of the source media; must be a language the transcription model supports. Any region or script subtag is ignored, since transcription is per-language. Omit to auto-detect.

        model_id : typing.Optional[ProjectCreateRequestModelId]
            Default dubbing model id ('dubbing_v1' or 'dubbing_v2') for the project's language targets; a target may override it. Omit to use the system default.

        keyterms : typing.Optional[typing.List[str]]
            Key terms to bias transcription/translation toward (e.g. product or brand names). At most 1000 terms; each term at most 50 characters and 5 words; the characters `<>{}[]\\` are not allowed.

        webhook_ids : typing.Optional[typing.List[str]]
            Ids of workspace webhooks to notify when this project becomes ready or fails, and when any of its languages completes or fails. At most 3; each must be a webhook configured in your workspace.

        target_language : typing.Optional[str]
            Optional shortcut: also create a language target in this BCP-47 language, queued to start once the project is ready. Must be a language the dubbing model supports, and a region-qualified tag must be one of the supported dialects.

        transcript : typing.Optional[core.File]
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingProjectResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.create(
                source_url="https://example.com/promo.mp4",
                source_language="en",
                reference="Q3 marketing video",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            file=file,
            source_url=source_url,
            reference=reference,
            source_language=source_language,
            model_id=model_id,
            keyterms=keyterms,
            webhook_ids=webhook_ids,
            target_language=target_language,
            transcript=transcript,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DubbingProjectResponse:
        """
        Full project detail, including its language target ids.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project to fetch.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DubbingProjectResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.get(
                project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(project_id, request_options=request_options)
        return _response.data

    async def delete(self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        Delete a project and its language targets.

        Parameters
        ----------
        project_id : str
            Identifier of the dubbing project to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.dubbing.project.delete(
                project_id="proj_1601kwkyxp0hfzvtmyxwqxx6mcy3",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(project_id, request_options=request_options)
        return _response.data

    @property
    def language(self):
        if self._language is None:
            from .language.client import AsyncLanguageClient  # noqa: E402

            self._language = AsyncLanguageClient(client_wrapper=self._client_wrapper)
        return self._language

    @property
    def transcript(self):
        if self._transcript is None:
            from .transcript.client import AsyncTranscriptClient  # noqa: E402

            self._transcript = AsyncTranscriptClient(client_wrapper=self._client_wrapper)
        return self._transcript
